@@ -38,21 +38,21 @@ pub fn cli<'a>() -> App<'a> {
             .multiple(false)
             .long("db-url")
             .value_name("HOST")
-            .about("Overwrite the database host set via configuration. Can also be overriden via environment, but this setting has presendence.")
+            .about("Overwrite the database host set via configuration. Can also be overriden via environment, but this setting has precedence.")
         )
         .arg(Arg::new("database_port")
             .required(false)
             .multiple(false)
             .long("db-port")
             .value_name("PORT")
-            .about("Overwrite the database port set via configuration. Can also be overriden via environment, but this setting has presendence.")
+            .about("Overwrite the database port set via configuration. Can also be overriden via environment, but this setting has precedence.")
         )
         .arg(Arg::new("database_user")
             .required(false)
             .multiple(false)
             .long("db-user")
             .value_name("USER")
-            .about("Overwrite the database user set via configuration. Can also be overriden via environment, but this setting has presendence.")
+            .about("Overwrite the database user set via configuration. Can also be overriden via environment, but this setting has precedence.")
         )
         .arg(Arg::new("database_password")
             .required(false)
@@ -60,14 +60,14 @@ pub fn cli<'a>() -> App<'a> {
             .long("db-password")
             .alias("db-pw")
             .value_name("PASSWORD")
-            .about("Overwrite the database password set via configuration. Can also be overriden via environment, but this setting has presendence.")
+            .about("Overwrite the database password set via configuration. Can also be overriden via environment, but this setting has precedence.")
         )
         .arg(Arg::new("database_name")
             .required(false)
             .multiple(false)
             .long("db-name")
             .value_name("NAME")
-            .about("Overwrite the database name set via configuration. Can also be overriden via environment, but this setting has presendence.")
+            .about("Overwrite the database name set via configuration. Can also be overriden via environment, but this setting has precedence.")
         )
 
         .subcommand(App::new("generate-completions")
